<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Moral
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function etc_pro_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// When menu is sticky.
	$menu_sticky = get_theme_mod( 'etc_pro_make_menu_sticky', false );
	if ( $menu_sticky ) {
		$classes[] = 'menu-sticky';
	}

	// When  color scheme is light or dark.
	$color_scheme = get_theme_mod( 'etc_pro_color_scheme', 'lite' );
	$classes[] = esc_attr( $color_scheme ). '-version';
	
	// When global archive layout is checked.

	if ( is_archive() || etc_pro_is_latest_posts() || etc_pro_is_frontpage_blog() || is_404() || is_search() ) {
		$classes[] = 'no-sidebar';
	} elseif ( is_single() ) { // When global post sidebar is checked.
        if ( ! is_active_sidebar( 'sidebar-1' ) ) {
          $classes[] = 'no-sidebar';
        }
    else {
      $etc_pro_post_sidebar_meta = get_post_meta( get_the_ID(), 'etc-pro-select-sidebar', true );
      if ( ! empty( $etc_pro_post_sidebar_meta ) ) {
        $classes[] = esc_attr( $etc_pro_post_sidebar_meta ) . '-sidebar';
      } else {
        $global_post_sidebar = get_theme_mod( 'etc_pro_global_post_layout', 'right' ); 
        $classes[] = esc_attr( $global_post_sidebar ) . '-sidebar';
      }
    }
    	
	} elseif ( is_page() ) {
    if ( ! is_active_sidebar( 'sidebar-1' ) ) {
      $classes[] = 'no-sidebar';
    }
    else {
      $page_id = get_the_ID();

      $etc_pro_page_sidebar_meta = get_post_meta( $page_id, 'etc-pro-select-sidebar', true );
        if ( ! empty( $etc_pro_page_sidebar_meta ) ) {
            $classes[] = esc_attr( $etc_pro_page_sidebar_meta ) . '-sidebar';
      } else {
        $global_page_sidebar = get_theme_mod( 'etc_pro_global_page_layout', 'right' ); 
        $classes[] = esc_attr( $global_page_sidebar ) . '-sidebar';
      }
    }
		
	}

	// Site layout classes
	$site_layout = get_theme_mod( 'etc_pro_site_layout', 'wide' );
	$classes[] = esc_attr( $site_layout ) . '-layout';

    // search 
    $search_enable = get_theme_mod( 'etc_pro_show_search', true );
    if ( ! $search_enable )  {
        $classes[] = 'search-disabled';
    }

  // blog layout
  if ( is_archive() || etc_pro_is_latest_posts() || is_search() || etc_pro_is_frontpage_blog() ) {
        $global_blog_layout = get_theme_mod( 'etc_pro_archive_layout', 'classic-design' ); 
        $classes[] = esc_attr( $global_blog_layout );
  }
  

	return $classes;
}
add_filter( 'body_class', 'etc_pro_body_classes' );

function etc_pro_post_classes( $classes ) {
	if ( etc_pro_is_page_displays_posts() ) {
		
		if( has_post_thumbnail() ) {
			$classes[] = 'has-post-thumbnail';
		} else {
			$classes[] = 'no-post-thumbnail';
		}
	}
  
	return $classes;
}
add_filter( 'post_class', 'etc_pro_post_classes' );

/**
 * Excerpt length
 * 
 * @since Moral 1.0.0
 * @return Excerpt length
 */
function etc_pro_excerpt_length( $length ){
	if ( is_admin() ) {
		return $length;
	}

	$length = get_theme_mod( 'etc_pro_archive_excerpt_length', 25 );
	return $length;
}
add_filter( 'excerpt_length', 'etc_pro_excerpt_length', 999 );

/**
 * Excerpt more
 * 
 * @since Moral 1.0.0
 * @return Excerpt more
 */
if ( ! function_exists( 'etc_pro_excerpt_more' ) ) :
    function etc_pro_excerpt_more( $more ){
        if ( is_admin() ) {
            return $more;
        }

        return '&hellip;';
    }
endif;
add_filter( 'excerpt_more', 'etc_pro_excerpt_more' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function etc_pro_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'etc_pro_pingback_header' );


/**
 * Checks to see if we're on the homepage or not.
 */
function etc_pro_is_frontpage() {
	return ( is_front_page() && ! is_home() );
}

/**
 * Checks to see if Static Front Page is set to "Your latest posts".
 */
function etc_pro_is_latest_posts() {
	return ( is_front_page() && is_home() );
}

/**
 * Checks to see if Static Front Page is set to "Posts page".
 */
function etc_pro_is_frontpage_blog() {
	return ( is_home() && ! is_front_page() );
}

/**
 * Checks to see if the current page displays any kind of post listing.
 */
function etc_pro_is_page_displays_posts() {
	return ( etc_pro_is_frontpage_blog() || is_search() || is_archive() || etc_pro_is_latest_posts() );
}

/**
 * Pagination in archive/blog/search pages.
 */
function etc_pro_posts_pagination() { 
	$archive_pagination = get_theme_mod( 'etc_pro_archive_pagination_type', 'numeric' );
	if ( 'disable' === $archive_pagination ) {
		return;
	}
	if ( 'numeric' === $archive_pagination ) {
		the_posts_pagination( array(
            'prev_text'          => etc_pro_get_svg( array( 'icon' => 'left' ) ) . esc_html__( 'Previous', 'etc-pro' ),
            'next_text'          => esc_html__( 'Next', 'etc-pro' ) . etc_pro_get_svg( array( 'icon' => 'right' ) ),
        ) );
	} elseif ( 'older_newer' === $archive_pagination ) {
        the_posts_navigation( array(
            'prev_text'          => etc_pro_get_svg( array( 'icon' => 'left' ) ) . '<span>'. esc_html__( 'Older', 'etc-pro' ) .'</span>',
            'next_text'          => '<span>'. esc_html__( 'Newer', 'etc-pro' ) .'</span>' . etc_pro_get_svg( array( 'icon' => 'right' ) ),
        )  );
	}
}

function etc_pro_custom_color_scheme() {
    if ( 'custom' != get_theme_mod( 'etc_pro_color_scheme' ) ) {
        return;
    }
    $color = get_theme_mod( 'etc_pro_custom_color_scheme', '#ff8737' );
    $custom_css = '
           	/*----------------------------------------
           		Color
           	------------------------------------------*/
           	a,
            #filter-posts ul li.active a,
            #filter-posts ul li a:hover,
            #filter-posts ul li a:focus,
            .main-navigation ul#primary-menu li.current-menu-item > a,
            .main-navigation ul#primary-menu li:hover > a,
            .secondary-navigation ul#secondary-menu li.current-menu-item > a,
            .secondary-navigation ul#secondary-menu li:hover > a,
            .main-navigation a:hover,
            .main-navigation ul.nav-menu > li > a:hover,
            .secondary-navigation a:hover,
            .secondary-navigation ul.nav-menu > li > a:hover,
            .post-navigation a:hover, 
            .posts-navigation a:hover,
            .post-navigation a:focus, 
            .posts-navigation a:focus,
            .pagination .page-numbers.prev,
            .pagination .page-numbers.next,
            .pagination .page-numbers.next:hover,
            .pagination .page-numbers.next:focus,
            .pagination .page-numbers.prev:hover,
            .pagination .page-numbers.prev:focus,
            .widget_popular_post h3 a:hover,
            .widget_popular_post h3 a:focus,
            .widget_popular_post a:hover time,
            .widget_popular_post a:focus time,
            .widget_latest_post h3 a:hover,
            .widget_latest_post h3 a:focus,
            .widget_latest_post a:hover time,
            .widget_latest_post a:focus time,
            .widget_featured_post h3 a:hover,
            .widget_featured_post h3 a:focus,
            .widget_featured_post a:hover time,
            .widget_featured_post a:focus time,
            .widget_popular_post a time,
            .widget_popular_post time,
            .widget_latest_post a time,
            .widget_latest_post time,
            .widget_featured_post a time,
            .widget_featured_post time,
            #secondary a:hover,
            #secondary a:focus,
            #secondary .textwidget a,
            .post-categories a,
            .singular-section span.byline a:hover,
            .singular-section span.byline a:focus,
            .reply a:hover,
            .reply a:focus,
            .comment-meta .url:hover,
            .comment-meta .url:focus,
            .comment-metadata a,
            .comment-metadata a time,
            .btn,
            .modern-design .posted-on,
            .sleek-design .posted-on,
            .modern-design ul.products > li .posted-on,
            .sleek-design ul.products > li .posted-on,
            .post-archive article .entry-container .entry-title a:hover,
            .post-archive article .entry-container .entry-title a:focus,
            .cat-links a:hover,
            .cat-links a:focus,
            .woocommerce-loop-product__title a:hover,
            .woocommerce-loop-product__title a:focus,
            .products li .button:hover,
            .products li .button:focus,
            ins,
            a.page-numbers,
            .woocommerce ul.products li.product .price span.woocommerce-Price-amount.amount,
            .product_meta > span a:hover,
            .product_meta > span a:focus,
            .woocommerce-product-rating a:hover,
            .woocommerce-product-rating a:focus,
            .summary.entry-summary .price .woocommerce-Price-amount.amount,
            ul.products li .entry-container a:hover h2,
            .woocommerce-MyAccount-content .woocommerce-Button.button:hover,
            .woocommerce-info::before,
            .woocommerce-message::before,
            #colophon a:hover,
            #colophon a:focus,
            #colophon .site-info a,
            .woocommerce a.added_to_cart:hover, 
            .woocommerce a.added_to_cart:focus,
            .singular-section span.tags-links a:hover,
            .singular-section span.tags-links a:focus {
           	    color: ' . esc_attr( $color ) . ';
           	}

           	.main-navigation ul#primary-menu li:hover > svg,
            .main-navigation li.menu-item-has-children:hover > a > svg,
            .main-navigation li.menu-item-has-children > a:hover > svg,
            .secondary-navigation ul#secondary-menu li:hover > svg,
            .secondary-navigation ul#secondary-menu > li.current-menu-item > a > svg,
            .main-navigation ul.nav-menu > li > a.search:hover svg.icon-search,
            .main-navigation ul.nav-menu > li > a.search:focus svg.icon-search,
            .main-navigation li.search-menu a:hover svg,
            .main-navigation li.search-menu a:focus svg,
            .main-navigation li.search-menu a.search-active svg,
            .pagination .page-numbers.prev:hover svg, 
            .pagination .page-numbers.next:hover svg,
            .widget_search form.search-form .search-submit:hover svg,
            .widget_search form.search-form .search-submit:focus svg,
            .widget svg,
            .navigation.posts-navigation a:hover svg, 
            .navigation.post-navigation a:hover svg {
           		fill: ' . esc_attr( $color ) . ';
           	}

           	/*----------------------------------------
           		Background Color
           	------------------------------------------*/
           	.backtotop,
            #respond input[type="submit"],
            .pagination .page-numbers.current,
            .pagination .page-numbers:hover,
            .pagination .page-numbers:focus,
            .widget_search form.search-form .search-submit:hover,
            .widget_search form.search-form .search-submit:focus,
            input[type="submit"]:hover,
            input[type="submit"]:focus,
            .jetpack_subscription_widget input[type="submit"],
            #secondary .jetpack_subscription_widget input[type="submit"]:hover,
            #secondary .jetpack_subscription_widget input[type="submit"]:focus,
            #infinite-handle span button,
            #infinite-handle span button:hover,
            #infinite-handle span button:focus,
            .page-numbers.current,
            .woocommerce nav.woocommerce-pagination ul li a:focus, 
            .woocommerce nav.woocommerce-pagination ul li a:hover, 
            .woocommerce nav.woocommerce-pagination ul li span.current,
            .woocommerce-MyAccount-content button.woocommerce-Button.button,
            .woocommerce .cart .button, 
            .woocommerce .cart input.button,
            .woocommerce #respond input#submit.disabled, 
            .woocommerce #respond input#submit:disabled, 
            .woocommerce #respond input#submit:disabled[disabled], 
            .woocommerce a.button.disabled, 
            .woocommerce a.button:disabled, 
            .woocommerce a.button:disabled[disabled], 
            .woocommerce button.button.disabled, 
            .woocommerce button.button:disabled, 
            .woocommerce button.button:disabled[disabled], 
            .woocommerce input.button.disabled, 
            .woocommerce input.button:disabled, 
            .woocommerce input.button:disabled[disabled],
            #add_payment_method .wc-proceed-to-checkout a.checkout-button, 
            .woocommerce-cart .wc-proceed-to-checkout a.checkout-button, 
            .woocommerce-checkout .wc-proceed-to-checkout a.checkout-button,
            .woocommerce #respond input#submit.alt, 
            .woocommerce a.button.alt, 
            .woocommerce button.button.alt, 
            .woocommerce input.button.alt,
            .woocommerce-page .woocommerce-message .button,
            .woocommerce #review_form #respond .form-submit input,
            .woocommerce-store-notice, 
            p.demo_store,
            .woocommerce form.login .button.woocommerce-Button.button,
            form.woocommerce-ResetPassword.lost_reset_password .button.woocommerce-Button.button,
            .wpcf7 input[type="submit"] {
           		background-color: ' . esc_attr( $color ) . ';
           	}

           	/*----------------------------------------
           		Border Color
           	------------------------------------------*/
           	.woocommerce .summary.entry-summary .quantity .qty {
           		border-color: ' . esc_attr( $color ) . ';
           	}

            .woocommerce-info,
            .woocommerce-message {
                border-top-color: ' . esc_attr( $color ) . ';
            }

       		.woocommerce div.product .woocommerce-tabs ul.tabs li.active {
       			border-bottom-color: ' . esc_attr( $color ) . ';
       		}
        ';
    wp_add_inline_style( 'etc-pro-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'etc_pro_custom_color_scheme' );

// Add auto p to the palces where get_the_excerpt is being called.
add_filter( 'get_the_excerpt', 'wpautop' );

function etc_pro_background_color() {
   $bg_color = get_background_color();
   $custom_css = '
       body {
           background-color: #' . esc_attr( $bg_color ) . '
       }';
   wp_add_inline_style( 'etc-pro-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'etc_pro_background_color' );

/**
 * Get an array of cat id and title.
 * 
 */
function etc_pro_get_post_tags_choices() {
    $choices = array( 0 => esc_html__( '--Select--', 'etc-pro' ) );
    $posttags = get_terms( array(
        'taxonomy' => 'post_tag',
        'hide_empty' => false,
    ) );

    foreach ( $posttags as $tag ) {
        $id = $tag->term_id;
        $title = $tag->name;
        $choices[ $id ] = $title;
    }

    return $choices;
}
